src.imagedata package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   src.imagedata.apps
   src.imagedata.archives
   src.imagedata.formats
   src.imagedata.transports

Submodules
----------

src.imagedata.axis module
-------------------------

.. automodule:: src.imagedata.axis
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.cmdline module
----------------------------

.. automodule:: src.imagedata.cmdline
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.collections module
--------------------------------

.. automodule:: src.imagedata.collections
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.header module
---------------------------

.. automodule:: src.imagedata.header
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.image\_data module
--------------------------------

.. automodule:: src.imagedata.image_data
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.list\_plugins module
----------------------------------

.. automodule:: src.imagedata.list_plugins
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.readdata module
-----------------------------

.. automodule:: src.imagedata.readdata
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.series module
---------------------------

.. automodule:: src.imagedata.series
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.viewer module
---------------------------

.. automodule:: src.imagedata.viewer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src.imagedata
   :members:
   :undoc-members:
   :show-inheritance:
